<?php

namespace Pinpoint\DeliveryDate\Model\Config\Shipping\Source;

/**
 * Class ShippingMethods
 * @package Pinpoint\DeliveryDate\Model\Config\Shipping\Source
 */
class ShippingMethods extends \Magento\Shipping\Model\Config\Source\Allmethods
{
    /**
     * @param bool $isActiveOnlyFlag
     * @return array
     */
    public function toOptionArray($isActiveOnlyFlag = false)
    {
        $methods = [['value' => '', 'label' => '']];
        $carriers = $this->_shippingConfig->getAllCarriers();
        foreach ($carriers as $carrierCode => $carrierModel) {
            if (!$carrierModel->isActive() && (bool)$isActiveOnlyFlag === true) {
                continue;
            }

            $carrierMethods = $carrierModel->getAllowedMethods();
            if (!$carrierMethods) {
                continue;
            }

            $carrierTitle = $this->_scopeConfig->getValue(
                'carriers/' . $carrierCode . '/title',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE
            );

            $methods[$carrierCode] = ['label' => $carrierTitle, 'value' => []];
            foreach ($carrierMethods as $methodCode => $methodTitle) {
                if (!empty($methodTitle)) {
                    if (!is_array($methodTitle)) {
                        $methodTitle = [$methodTitle];
                    }

                    foreach ($methodTitle as $title) {
                        $methods[$carrierCode]['value'][] = [
                            'value' => $carrierCode . '_' . $methodCode,
                            'label' => '[' . $carrierCode . '] ' . $title,
                        ];
                    }
                }
            }
        }

        return $methods;
    }
}
